==> haskell-puresat-0.1-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-puresat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-puresat-z-internal
version:              0.1
package-name:         puresat
lib-name:             internal
id:                   puresat-0.1-Kc0UbRDRUfz7esxB99t56a-internal
key:                  puresat-0.1-Kc0UbRDRUfz7esxB99t56a-internal
license:              BSD-3-Clause
copyright:            (c) 2024 Oleg Grenrus
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/puresat
synopsis:             Pure Haskell SAT-solver
description:
    SAT Solver implemented in Haskell.

    PureSAT uses DPLL with non-chronological backtracking and learning of binaary clauses.
    Solver is in no-comparison to the state of the art solvers, but it'\''s fast enough to solve sudoku.

category:             Data
abi:                  dc537415797daee34928511058799263
exposed-modules:
    PureSAT.Assert PureSAT.Base PureSAT.Boost PureSAT.Clause2
    PureSAT.LBool PureSAT.LCG PureSAT.Level PureSAT.LitSet
    PureSAT.LitTable PureSAT.LitVar PureSAT.Main
    PureSAT.PartialAssignment PureSAT.Prim PureSAT.Satisfied
    PureSAT.SparseMaxHeap PureSAT.SparseSet PureSAT.Stats PureSAT.Trail
    PureSAT.Utils PureSAT.VarSet PureSAT.Vec

import-dirs:          /usr/lib/ghc-9.6.6/site-local/puresat-0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/puresat-0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/puresat-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-puresat
hs-libraries:         HSpuresat-0.1-Kc0UbRDRUfz7esxB99t56a-internal
depends:
    base-4.18.2.1 containers-0.6.7
    primitive-0.9.1.0-LZUymL07sjCJKODqCvDEyu

haddock-interfaces:   /usr/share/doc/haskell-puresat/html/puresat.haddock
haddock-html:         /usr/share/doc/haskell-puresat/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-puresat-z-dimacs
version:              0.1
package-name:         puresat
lib-name:             dimacs
id:                   puresat-0.1-lWkl8mMPlL6cIPfrtmvf-dimacs
key:                  puresat-0.1-lWkl8mMPlL6cIPfrtmvf-dimacs
license:              BSD-3-Clause
copyright:            (c) 2024 Oleg Grenrus
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/puresat
synopsis:             Pure Haskell SAT-solver
description:
    SAT Solver implemented in Haskell.

    PureSAT uses DPLL with non-chronological backtracking and learning of binaary clauses.
    Solver is in no-comparison to the state of the art solvers, but it'\''s fast enough to solve sudoku.

category:             Data
abi:                  1b42209ef61e32f8970cb5342ffa8610
exposed-modules:      PureSAT.DIMACS
import-dirs:          /usr/lib/ghc-9.6.6/site-local/puresat-0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/puresat-0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/puresat-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-puresat
hs-libraries:         HSpuresat-0.1-lWkl8mMPlL6cIPfrtmvf-dimacs
depends:
    base-4.18.2.1 bytestring-0.11.5.3 parsec-3.1.16.1
    puresat-0.1-Kc0UbRDRUfz7esxB99t56a-internal

haddock-interfaces:   /usr/share/doc/haskell-puresat/html/puresat.haddock
haddock-html:         /usr/share/doc/haskell-puresat/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 puresat
version:              0.1
visibility:           public
id:                   puresat-0.1-4Dg05zNWh4L2J6kJS6gIK
key:                  puresat-0.1-4Dg05zNWh4L2J6kJS6gIK
license:              BSD-3-Clause
copyright:            (c) 2024 Oleg Grenrus
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/puresat
synopsis:             Pure Haskell SAT-solver
description:
    SAT Solver implemented in Haskell.

    PureSAT uses DPLL with non-chronological backtracking and learning of binaary clauses.
    Solver is in no-comparison to the state of the art solvers, but it'\''s fast enough to solve sudoku.

category:             Data
abi:                  8e2ae325f19bfa010bc1fde2f7557268
exposed:              True
exposed-modules:      Control.Monad.SAT PureSAT
hidden-modules:       EST
import-dirs:          /usr/lib/ghc-9.6.6/site-local/puresat-0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/puresat-0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/puresat-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-puresat
hs-libraries:         HSpuresat-0.1-4Dg05zNWh4L2J6kJS6gIK
depends:
    base-4.18.2.1 containers-0.6.7
    puresat-0.1-Kc0UbRDRUfz7esxB99t56a-internal

haddock-interfaces:   /usr/share/doc/haskell-puresat/html/puresat.haddock
haddock-html:         /usr/share/doc/haskell-puresat/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-puresat-0.1-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-puresat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-puresat-z-internal
version:              0.1
package-name:         puresat
lib-name:             internal
id:                   puresat-0.1-8nNA2mkYdwHBJY622MUtRP-internal
key:                  puresat-0.1-8nNA2mkYdwHBJY622MUtRP-internal
license:              BSD-3-Clause
copyright:            (c) 2024 Oleg Grenrus
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/puresat
synopsis:             Pure Haskell SAT-solver
description:
    SAT Solver implemented in Haskell.

    PureSAT uses DPLL with non-chronological backtracking and learning of binaary clauses.
    Solver is in no-comparison to the state of the art solvers, but it'\''s fast enough to solve sudoku.

category:             Data
abi:                  08b7f44ebe49e7539cb9a6a807c7bca3
exposed-modules:
    PureSAT.Assert PureSAT.Base PureSAT.Boost PureSAT.Clause2
    PureSAT.LBool PureSAT.LCG PureSAT.Level PureSAT.LitSet
    PureSAT.LitTable PureSAT.LitVar PureSAT.Main
    PureSAT.PartialAssignment PureSAT.Prim PureSAT.Satisfied
    PureSAT.SparseMaxHeap PureSAT.SparseSet PureSAT.Stats PureSAT.Trail
    PureSAT.Utils PureSAT.VarSet PureSAT.Vec

import-dirs:          /usr/lib/ghc-9.6.6/site-local/puresat-0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/puresat-0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/puresat-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-puresat
hs-libraries:         HSpuresat-0.1-8nNA2mkYdwHBJY622MUtRP-internal
depends:
    base-4.18.2.1 containers-0.6.7
    primitive-0.9.1.0-6uX3awsflEb6ebVZsasp0o

haddock-interfaces:   /usr/share/doc/haskell-puresat/html/puresat.haddock
haddock-html:         /usr/share/doc/haskell-puresat/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-puresat-z-dimacs
version:              0.1
package-name:         puresat
lib-name:             dimacs
id:                   puresat-0.1-FUMvvEnv6Js7HnTBTLXB4P-dimacs
key:                  puresat-0.1-FUMvvEnv6Js7HnTBTLXB4P-dimacs
license:              BSD-3-Clause
copyright:            (c) 2024 Oleg Grenrus
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/puresat
synopsis:             Pure Haskell SAT-solver
description:
    SAT Solver implemented in Haskell.

    PureSAT uses DPLL with non-chronological backtracking and learning of binaary clauses.
    Solver is in no-comparison to the state of the art solvers, but it'\''s fast enough to solve sudoku.

category:             Data
abi:                  57feaecd835c5b220c43b18317ca1a7e
exposed-modules:      PureSAT.DIMACS
import-dirs:          /usr/lib/ghc-9.6.6/site-local/puresat-0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/puresat-0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/puresat-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-puresat
hs-libraries:         HSpuresat-0.1-FUMvvEnv6Js7HnTBTLXB4P-dimacs
depends:
    base-4.18.2.1 bytestring-0.11.5.3 parsec-3.1.16.1
    puresat-0.1-8nNA2mkYdwHBJY622MUtRP-internal

haddock-interfaces:   /usr/share/doc/haskell-puresat/html/puresat.haddock
haddock-html:         /usr/share/doc/haskell-puresat/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 puresat
version:              0.1
visibility:           public
id:                   puresat-0.1-KvedEWQgLId4lqfVJdyJbn
key:                  puresat-0.1-KvedEWQgLId4lqfVJdyJbn
license:              BSD-3-Clause
copyright:            (c) 2024 Oleg Grenrus
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/puresat
synopsis:             Pure Haskell SAT-solver
description:
    SAT Solver implemented in Haskell.

    PureSAT uses DPLL with non-chronological backtracking and learning of binaary clauses.
    Solver is in no-comparison to the state of the art solvers, but it'\''s fast enough to solve sudoku.

category:             Data
abi:                  1f4519103adceb972fe4e4cb207b19e0
exposed:              True
exposed-modules:      Control.Monad.SAT PureSAT
hidden-modules:       EST
import-dirs:          /usr/lib/ghc-9.6.6/site-local/puresat-0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/puresat-0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/puresat-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-puresat
hs-libraries:         HSpuresat-0.1-KvedEWQgLId4lqfVJdyJbn
depends:
    base-4.18.2.1 containers-0.6.7
    puresat-0.1-8nNA2mkYdwHBJY622MUtRP-internal

haddock-interfaces:   /usr/share/doc/haskell-puresat/html/puresat.haddock
haddock-html:         /usr/share/doc/haskell-puresat/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
